% ----------------------
% SS.m
% ----------------------
% computes steady state and fills the values for year 't'
% in:   DF
% out:  resid
% ----------------------

function resid = SS(foreignassets)

global t rho gam sigma psi
global Y Div w I J V K H A Omega C TB DF edy r
global A_0 alpha L ell N NB delta

DF(t)    = foreignassets;

N(t)     = NB(t)/(1-gam(t));
L(t)     = ell(t)*N(t);
K(t)     = L(t)*(alpha*A_0/(r(t)+delta))^(1/(1-alpha));
Y(t)     = A_0*K(t)^alpha*L(t)^(1-alpha);
w(t)     = (1-alpha)*Y(t)/L(t);
I(t)     = delta*K(t);
J(t)     = 1/2*psi*K(t)*(I(t)/K(t)-delta)^2;
Div(t)   = Y(t)-w(t)*L(t)-I(t)-J(t);
V(t)     = (1+r(t))/r(t)*Div(t);
H(t)     = (1+r(t))/(r(t)+1-gam(t))*w(t)*L(t);
A(t)     = DF(t)+V(t);
Omega(t) = 1/(1-(1/(1+rho))^sigma*(1+r(t))^(sigma-1)*gam(t));
C(t)     = (A(t)+H(t))/Omega(t);
TB(t)    = Y(t)-C(t)-I(t)-J(t);
edy(t)   = I(t)+J(t)+C(t)+TB(t)-Y(t);

resid = DF(t)+(1+r(t))/r(t)*TB(t);

end