% ----------------------
% runme.m
% ----------------------
% 'Blanchard_unanticipated': Chapter 4.4
% March 3, 2014 Philip Schuster
% 
% computes the transition of a shock
% in a Blanchard model (open economy)
% with unanticipated shocks
% ----------------------

clear all;  % clear all variables
clc;        % clear screen

fprintf('BLANCHARD MODEL OF OPEN ECONOMY - TRANSITIONAL DYNAMICS\n\n');

% DATA AND CALIBRATION
global tend findrootmethod

findrootmethod = 1; % use simple Newton-Raphson method (=1)
tend    = 400; % number of periods

param; % loads exogenous parameters
calib; % calibrates the model

% COMPUTE JACOBIAN FOR DYNAMIC SOLUTION
jacob = compjacob(guess);

% COMPUTE INITIAL STEADY STATE
ISS;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%           Anticipated shocks             %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% REFORMS
reforms;
%ell(40:tend)= ell0*1.1*ones(1,tend-40+1);

% COMPUTE FINAL STEADY STATE
FSS;

% SOLVE FOR TRANSITIONS
[actual, retcode] = gft(guess,jacob);   % Generalized Fair-Taylor
%[actual, retcode] = ft(guess);         % Original Fair-Taylor

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%          Unanticipated shocks            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% REFORMS
tstart          = 40;
ell(tstart:tend)= ell0*1.1*ones(1,tend-tstart+1);

% COMPUTE FINAL STEADY STATE
FSS;

% SOLVE FOR TRANSITIONS
[actual, retcode] = gft(guess,jacob,1,1,tstart);   % Generalized Fair-Taylor
%[actual, retcode] = ft(guess,1,tstart);           % Original Fair-Taylor

